from turcar import launch, report_time
import os
import requests

from turcar.check_for_updates import CheackUpdates
import platform

# 获取当前操作系统
current_os = platform.system()
report_time("Before launch")
response = requests.get('https://pypi.org/pypi/turcar/json')
if response.status_code == 200:
    data = response.json()
    # 获取项目最新版本
    version = data["info"]["version"]
    # 获取当前脚本所在目录
    current_dir = os.path.dirname(os.path.abspath(__file__))
    # 指定要获取内容的文件名
    file_name = "VERSION"
    # 拼接文件路径
    file_path = os.path.join(current_dir, file_name)
    # 空校验
    if os.path.exists(file_path):
        # 打开文件并读取内容
        with open(file_path, 'r') as file:
            content = file.read()
            # print(f"File: {file_name}")
            print(f"VERSION: {content}")
            if version != content:
                if current_os == "Windows":
                    pass
                else:  # 默认为Ubuntu或其他Linux发行版
                    cheack = CheackUpdates()
                    cheack.cheack_version(version)

launch()



import os.path
import sys

from setuptools import find_packages, setup


def recursive_files(directory):
    paths = []
    for (path, _, filenames) in os.walk(directory):
        for filename in filenames:
            if not filename.endswith(".pyc") and filename != "registered.json":
                paths.append(os.path.join('..', path, filename))
    return paths

if sys.version_info < (3, 8):
    raise RuntimeError("turcar requires Python 3.8 or later")

setupdir = os.path.dirname(__file__)

with open(os.path.join(setupdir, "turcar", "VERSION"), encoding="ASCII") as f:
    version = f.read().strip()

requirements = []
for line in open(os.path.join(setupdir, "requirements.txt"), encoding="ASCII"):
    if line.strip() and not line.startswith("#"):
        requirements.append(line)

setup(
    name="turcar",
    version=version,
    description="Python IDE for beginners",
    long_description="turcar is a simple Python IDE with features useful for learning programming. See https://turcar.org for more info.",
    url="https://turcar.org",
    author="Aivar Annamaa and others",
    author_email="turcar@googlegroups.com",
    license="MIT",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: MacOS X",
        "Environment :: Win32 (MS Windows)",
        "Environment :: X11 Applications",
        "Intended Audience :: Developers",
        "Intended Audience :: Education",
        "Intended Audience :: End Users/Desktop",
        "License :: Freeware",
        "License :: OSI Approved :: MIT License",
        "Natural Language :: English",
        "Operating System :: MacOS",
        "Operating System :: Microsoft :: Windows",
        "Operating System :: POSIX",
        "Operating System :: POSIX :: Linux",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Topic :: Education",
        "Topic :: Software Development",
        "Topic :: Software Development :: Debuggers",
        "Topic :: Text Editors",
    ],
    keywords="IDE education debugger",
    project_urls={
        "Source code": "https://github.com/turcar/turcar",
        "Bug tracker": "https://github.com/turcar/turcar/issues",
    },
    platforms=["Windows", "macOS", "Linux"],
    install_requires=requirements,
    python_requires=">=3.8",
    packages=find_packages(),
    package_data={
        "": ["VERSION", "defaults.ini", "res/*", "dbus/*"]
            + recursive_files("turcar/locale")
            + recursive_files("turcar/vendored_libs"),
        "turcar.plugins.help": ["*.rst"],
        "turcar.plugins.pi": ["res/**"],
        "turcar.plugins.printing": ["*.html"],
        "turcar.plugins.micropython": ["*api_stubs/**"],
        "turcar.plugins.circuitpython": ["*api_stubs/**"],
        "turcar.plugins.microbit": ["*api_stubs/**"],
        "turcar.plugins.rp2040": ["*api_stubs/**"],
        "turcar.plugins.ev3": ["*api_stubs/**"],
        "turcar.plugins.prime_inventor": ["*api_stubs/**"],
        "turcar.plugins.esp": ["*api_stubs/**"],
        "turcar.plugins.mypy": ["typeshed_extras/*.pyi"],
    },
    entry_points={"gui_scripts": ["turcar = turcar:launch"]},
)
